@@ -5,13 +5,13 @@ package WWW::YaCyBlacklist;
 # ABSTRACT: a Perl module to parse and execute YaCy blacklists
 
 our $AUTHORITY = 'cpan:IBRAUN';
-$WWW::YaCyBlacklist::VERSION = '0.7.0';
+$WWW::YaCyBlacklist::VERSION = '0.1';
 
 use Moose;
 use Moose::Util::TypeConstraints;
 use IO::All;
 use URI::URL;
-require 5.8.0;
+require 5.6.0;
 
 
 # Needed if RegExps do not compile
@@ -31,7 +31,14 @@ has 'filename' => (
 has 'file_charset' => (
     is  => 'ro',
     isa => 'Str',
-    default => 'UTF-8',
+    default => 'cp1252', # YaCy files are encoded in ANSI
+    init_arg => undef,
+);
+
+has 'lines' => (
+    is  => 'rw',
+    isa => 'Int',
+    default => 0,
     init_arg => undef,
 );
 
@@ -52,7 +59,7 @@ has 'sortorder' => (
 
 has 'sorting' => (
     is  => 'rw',
-    isa => enum([qw[ alphabetical length origorder random reverse_host ]]),
+    isa => enum([qw[ alphabetical length origorder random reverse_host ]]),,
     default => 'origorder',
 );
 
@@ -82,7 +89,6 @@ sub read_from_array {
         if ( CORE::length $line > 0 ) {
             $hash{ $line }{ 'origorder' } = $self->origorder( $self->origorder + 1 );
             ( $hash{ $line }{ 'host' }, $hash{ $line }{ 'path' } ) = split /(?!\\)\/+?/, $line, 2;
-            $hash{ $line }{ 'path' } = '/' . $hash{ $line }{ 'path' };
             $hash{ $line }{ 'host_regex' } = $self->_check_host_regex( $hash{ $line }{ 'host' } );
         }
     }
@@ -96,11 +102,8 @@ sub read_from_files {
     my ($self, @files) = @_;
     my @lines;
 
-    grep { push( @lines, io( $_ )->encoding( $self->file_charset )->chomp->slurp ) } @files;
-
-    # chomp is not fully reliable with Windows files in Linux
-    grep { my $s = $_; $s =~ s/\r$//; $s } @lines;
-
+    grep { push( @lines, io( $_ )->encoding( $self->file_charset )->slurp ) } @files;
+    $self->lines(scalar @lines);
     $self->read_from_array( @lines );
 }
 
@@ -115,31 +118,27 @@ sub length {
 sub check_url {
 
     my $self = shift;
-    my $url = shift;
-    return 1 if $url !~ /^(ht|f)tps?\:\/\//i;
-    $url .= '/' if $url =~ /\:\/\/[\w\-\.]+$/;
-    $url = new URI $url;
+    my $url = new URI $_[0];
     my $pq = ( defined $url->query ) ? $url->path.'?'.$url->query : $url->path;
+    $pq =~ s/^\///;
 
     foreach my $pattern ( keys %{ $self->patterns } ) {
-
-        my $path = '^' . ${ $self->patterns }{ $pattern }{ path } . '$';
+        my $path = '^' . ${ $self->patterns }{ $pattern }{path} . '$';
         next if $pq !~ /$path/;
-        my $host = ${ $self->patterns }{ $pattern }{ host };
+        my $host = ${ $self->patterns }{ $pattern }{host};
 
-        if ( !${ $self->patterns }{ $pattern }{ host_regex } ) {
+        if ( !${ $self->patterns }{ $pattern }{host_regex} ) {
+            $host =~ s/\*/.*/g;
 
-            if ( index( ${ $self->patterns }{ $pattern }{ host }, '*') > -1 ) {
-
-                $host =~ s/\*/.*/g;
+            if ( ${ $self->patterns }{ $pattern }{host} =~ /\.\*$/ ) {
                 return 1 if $url->host =~ /^$host$/;
             }
             else {
-                return 1 if index( $url->host, ${ $self->patterns }{ $pattern }{ host } ) > -1 && $url->host =~ /^([\w\-]+\.)*$host$/;
+                return 1 if $url->host =~ /^(.+\.)?$host$/;
             }
         }
         else {
-            return 1 if $self->use_regex && $url->host  =~ /^$host$/;
+            return 1 if $url->host  =~ /^$host$/;
         }
     }
     return 0;
@@ -191,7 +190,7 @@ sub sort_list {
 sub store_list {
 
     my $self = shift;
-    join( "\n", $self->sort_list( ) ) > io( $self->filename );
+    join( "\n", $self->sort_list ) > io(  $self->filename )->encoding( $self->file_charset )->all;
 }
 
 1;
@@ -210,7 +209,7 @@ WWW::YaCyBlacklist - a Perl module to parse and execute YaCy blacklists
 
 =head1 VERSION
 
-version 0.7.0
+version 0.1
 
 =head1 SYNOPSIS
 
@@ -236,8 +235,7 @@ version 0.7.0
 
     $ycb->sortorder( 1 );
     $ycb->sorting( 'alphabetical' );
-    $ycb->filename( '/path/to/new.black' );
-    $ycb->store_list( );
+    $ycb->store_list( '/path/to/new.black' );
 
 =head1 METHODS
 
@@ -250,7 +248,7 @@ C<host> part is a regular expression (but the patterns remain in the list).
 
 =head2 C<filename =E<gt> '/path/to/file.black'> (default C<ycb.black>)
 
-This is the file printed by C<store_list>
+This is file printed by C<store_list>
 
 =head2 C<sortorder =E<gt>  0|1> (default C<0>)
 
@@ -297,15 +295,13 @@ Returns a list of patterns configured by C<sorting> and C<sortorder>.
 
 Prints the current list to a file. Executes C<sort_list( )>.
 
-=head1 OPERATIONAL NOTES
+=head1 Bugs
 
-C<WWW::YaCyBlacklist> checks the path part including the leading separator C</>. This protects against regexp compiling errors with leading quantifiers. So do not something like C<host.tld/^path> although YaCy allows this.
+YaCy does not allow host patterns with to stars at the time being. C<WWW::YaCyBlacklist> does not check for this but simply executes.
 
-C<check_url( )> alway returns true if the protocol of the URL is not C<https?> or C<ftps?>.
+=head1 Source
 
-=head1 BUGS
-
-YaCy does not allow host patterns with two ore more stars at the time being. C<WWW::YaCyBlacklist> does not check for this but simply executes. This is rather a YaCy bug.
+L<De:Blacklists|https://wiki.yacy.net/index.php/De:Blacklists> (German).
 
 If there is something you would like to tell me, there are different channels for you:
 
@@ -329,34 +325,16 @@ L<Contact form on my homepage|https://ingram-braun.net/erga/legal-notice-and-con
 
 =back
 
-=head1 SOURCE
+=head1 See also
 
 =over
 
 =item *
 
-L<De:Blacklists|https://wiki.yacy.net/index.php/De:Blacklists> (German).
-
-=item *
-
 L<Dev:APIlist|https://wiki.yacy.net/index.php/Dev:APIlist>
 
 =back
 
-=head1 SEE ALSO
-
-=over
-
-=item *
-
-L<YaCy homepage|https://yacy.net/>
-
-=item *
-
-L<YaCy community|https://community.searchlab.eu/>
-
-=back
-
 =head1 AUTHOR
 
 Ingram Braun <carlorff1@gmail.com>
